@@ -71,18 +71,18 @@ EogImage* eog_scroll_view_get_image       (EogScrollView *view);
 void     eog_scroll_view_set_scroll_wheel_zoom (EogScrollView *view, gboolean scroll_wheel_zoom);
 void     eog_scroll_view_set_zoom_upscale (EogScrollView *view, gboolean upscale);
 void     eog_scroll_view_set_zoom_multiplier (EogScrollView *view, gdouble multiplier);
-void	eog_scroll_view_set_zoom_mode (EogScrollView *view, EogZoomMode mode);
+void     eog_scroll_view_set_zoom_mode (EogScrollView *view, EogZoomMode mode);
 EogZoomMode	eog_scroll_view_get_zoom_mode (EogScrollView *view);
 void     eog_scroll_view_set_antialiasing_in (EogScrollView *view, gboolean state);
 void     eog_scroll_view_set_antialiasing_out (EogScrollView *view, gboolean state);
-void	eog_scroll_view_set_transparency_color (EogScrollView *view, GdkColor *color);
+void     eog_scroll_view_set_transparency_color (EogScrollView *view, GdkRGBA *color);
 void     eog_scroll_view_set_transparency (EogScrollView *view, EogTransparencyStyle style);
 gboolean eog_scroll_view_scrollbars_visible (EogScrollView *view);
 void	 eog_scroll_view_set_popup (EogScrollView *view, GtkMenu *menu);
 void	 eog_scroll_view_set_background_color (EogScrollView *view,
-					       const GdkColor *color);
+					       const GdkRGBA *color);
 void	 eog_scroll_view_override_bg_color (EogScrollView *view,
-					    const GdkColor *color);
+					    const GdkRGBA *color);
 void     eog_scroll_view_set_use_bg_color (EogScrollView *view, gboolean use);
 /* zoom api */
 void     eog_scroll_view_zoom_in          (EogScrollView *view, gboolean smooth);
